@@ -11,6 +11,7 @@ from typing import (
     Generic,
     Iterable,
     List,
+    Mapping,
     Optional,
     Sequence,
     TypeVar,
@@ -45,7 +46,6 @@ class Batch(Generic[K, T]):
 
 
 class DataLoader(Generic[K, T]):
-    queue: List[LoaderTask] = []
     batch: Optional[Batch[K, T]] = None
     cache: bool = False
     cache_map: Dict[K, Future]
@@ -116,6 +116,45 @@ class DataLoader(Generic[K, T]):
     def load_many(self, keys: Iterable[K]) -> Awaitable[List[T]]:
         return gather(*map(self.load, keys))
 
+    def clear(self, key: K):
+        if self.cache:
+            self.cache_map.pop(key, None)
+
+    def clear_many(self, keys: Iterable[K]):
+        if self.cache:
+            for key in keys:
+                self.cache_map.pop(key, None)
+
+    def clear_all(self):
+        if self.cache:
+            self.cache_map.clear()
+
+    def prime(self, key: K, value: T, force: bool = False):
+        self.prime_many({key: value}, force)
+
+    def prime_many(self, data: Mapping[K, T], force: bool = False):
+        # Populate the cache with the specified values
+        if self.cache:
+            for key, value in data.items():
+                if key not in self.cache_map or force:
+                    future: Future = Future(loop=self.loop)
+                    future.set_result(value)
+                    self.cache_map[key] = future
+
+        # For keys that are pending on the current batch, but the
+        # batch hasn't started fetching yet: Remove it from the
+        # batch and set to the specified value
+        if self.batch is not None and not self.batch.dispatched:
+            batch_updated = False
+            for task in self.batch.tasks:
+                if task.key in data.keys():
+                    batch_updated = True
+                    task.future.set_result(data[task.key])
+            if batch_updated:
+                self.batch.tasks = [
+                    task for task in self.batch.tasks if not task.future.done()
+                ]
+
 
 def should_create_new_batch(loader: DataLoader, batch: Batch) -> bool:
     if (
@@ -140,16 +179,18 @@ def get_current_batch(loader: DataLoader) -> Batch:
 
 
 def dispatch(loader: DataLoader, batch: Batch):
-    async def dispatch():
-        await dispatch_batch(loader, batch)
-
-    loader.loop.call_soon(create_task, dispatch())
+    loader.loop.call_soon(create_task, dispatch_batch(loader, batch))
 
 
 async def dispatch_batch(loader: DataLoader, batch: Batch) -> None:
     batch.dispatched = True
 
     keys = [task.key for task in batch.tasks]
+    if len(keys) == 0:
+        # Ensure batch is not empty
+        # Unlikely, but could happen if the tasks are
+        # overriden with preset values
+        return
 
     # TODO: check if load_fn return an awaitable and it is a list
 
