@@ -1,5 +1,6 @@
+import json
 from dataclasses import dataclass
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Mapping, Optional
 
 from typing_extensions import TypedDict
 
@@ -33,7 +34,14 @@ class GraphQLRequestData:
     operation_name: Optional[str]
 
 
-def parse_request_data(data: Dict) -> GraphQLRequestData:
+def parse_query_params(params: Dict[str, str]) -> Dict[str, Any]:
+    if "variables" in params:
+        params["variables"] = json.loads(params["variables"])
+
+    return params
+
+
+def parse_request_data(data: Mapping) -> GraphQLRequestData:
     if "query" not in data:
         raise MissingQueryError()
 
