@@ -22,7 +22,6 @@ if TYPE_CHECKING:
     from graphql import GraphQLResolveInfo
 
     from strawberry.field import StrawberryField
-    from strawberry.schema_directive import StrawberrySchemaDirective
 
 
 @dataclasses.dataclass(eq=False)
@@ -34,7 +33,7 @@ class TypeDefinition(StrawberryType):
     description: Optional[str]
     interfaces: List["TypeDefinition"]
     extend: bool
-    directives: Optional[Sequence[StrawberrySchemaDirective]]
+    directives: Optional[Sequence[object]]
     is_type_of: Optional[Callable[[Any, GraphQLResolveInfo], bool]]
 
     _fields: List["StrawberryField"]
